% Script that plots the output from simulations%
% Author:   Peter Tenfjord and Martin Bakke 
% Date:     01.06.2017


%  Plot calm water resistance and added resistance
figure
plot(t,Rtot/1000,'DisplayName','RTot')
hold on
plot(t,Res/1000,'DisplayName','Rcw')
plot(t,Raw/1000,'DisplayName','Raw')
plot(t,Raa/1000,'DisplayName','Raa')
title('Total Resistance and Resistance Components')
xlabel('Time [h]')
ylabel('Resistance [kN]')
legend('show')
dim = [0.7 0.35 0.1 0.2];
str = sprintf('Set Speed = %.2f \n Speed Loss: On',v_req_start);
annotation('textbox',dim,'String',str,'FitBoxToText','on')
hold off

%plot break power from main engine
figure
plot(t,(ME1PB/1000),'DisplayName','Break Power')
hold on
title('Break Power from Main Engine')
legend('show')
xlabel('Time Step')
ylabel('kW')
hold off


%% Plot simulated MetOcean data
% Plot histogram of significant wave heights encountered
figure
h1=histogram(Hs_sea,'DisplayName','Hs Sea');
hold on
h2=histogram(Hs_swl,'DisplayName','Hs Swl');
title('Distribution of encountered wave heights')
legend('show')
xlabel('Hs [m]')
ylabel('Probability')
h1.Normalization= 'probability';
h1.BinWidth=1;
h2.Normalization= 'probability';
h2.BinWidth=1;
hold off

% Plot histogram of wave periods encountered
figure
h3=histogram(Tp_sea,'DisplayName','Tp Sea');
hold on
h4=histogram(Tp_swl,'DisplayName','Tp Swl');
title('Distribution of encountered wave periods')
legend('show')
xlabel('Tp [s]')
ylabel('Probability')
h3.Normalization= 'probability';
h3.BinWidth=1;
h4.Normalization= 'probability';
h4.BinWidth=1;
hold off

%%plot attainable speed, wave height and direction.
figure
subplot(3,1,1)
plot(t,V_att,'DisplayName','V_att from Kwon')
title('Attainable speed during voyage')
legend('show')
xlabel('Time Step [h]')
ylabel('Attainable Speed [kts]')
dim = [0.7 0.63 0.1 0.2];
str = sprintf('Set Speed = %.2f',v_req_start);
annotation('textbox',dim,'String',str,'FitBoxToText','on')
subplot(3,1,2)
plot(t,Hs_sea,'DisplayName','Hs Sea')
title('Encountered Hs during voyage')
legend('show')
xlabel('Time Step [h]')
ylabel('Significant Wave Height [m]')
subplot(3,1,3)
plot(t,abs(wrapTo180(relD_sea)),'DisplayName','Relative Direction')
title('Relative direction of Hs and Course during voyage (0-180)')
legend('show')
xlabel('Time Step [h]')
ylabel('Relative Direction [deg]')

%% Plot the voyage 
figure('color','w');
ha = axesm('mapproj','mercator','maplatlim',[-75 75],'maplonlim',[90 -30]);
axis off, gridm on, framem on;
setm(ha,'MLineLocation',15,'PLineLocation',15);
mlabel on, plabel on;
%load coastlines;
hg = geoshow('landareas.shp'); %geoshow(coastlat,coastlon,'displaytype','line','color','b');
geoshow(LatPts,LonPts,'displaytype','line');

%Show animation of Voyage
figure('color','w');
ha = axesm('mapproj','mercator','maplatlim',[-75 75],'maplonlim',[90 -30]);
axis off, gridm on, framem on;
setm(ha,'MLineLocation',15,'PLineLocation',15);
mlabel on, plabel on;
%load coastlines;
hg = geoshow('landareas.shp'); %geoshow(coastlat,coastlon,'displaytype','line','color','b');
[x,y] = mfwdtran(LatPts,LonPts);
comet(x,y);
