% This function generates a set of distances and courses between waypoints
% based on origin, destination and ship speed
% Author:   Peter Tenfjord and Martin Bakke 
% Reference is made to: https://www.mathworks.com/help/map/navigation.html
% Date:     01.06.2017


function  [distnm_legs,course_legs] = get_route(origin, destination,ship_speed)


% draw a great circle between the points
gcpts = track2('gc',origin(1),origin(2),destination(1),destination(2));

% draw the rhumb line between the points
rhpts = track2('rh',origin(1),origin(2),destination(1),destination(2));

% draw N number of waypoints to approximate the great circle
% Use vessel speed and great circle length to calculate the number of waypoints needed with 3 hour intervals
dgc = distance('gc',origin,destination);
distgcnm = deg2nm(dgc); % great circle distance in nm (shortest route)
total_time=distgcnm/ship_speed; % Estimate the time spent on the journey [hours]
N=floor(total_time/8); % calculate the number of legs needed, 8 gives 3 hour steps

[latpts,lonpts]=gcwaypts(origin(1),origin(2),destination(1),destination(2), N);

% Compute headings and distances for the waypoint legs, and 
[course_legs, distnm_legs] = legs(latpts,lonpts,'rh');

%% plot the voyage
figure('color','w');
ha = axesm('mapproj','mercator','maplatlim',[-75 75],'maplonlim',[90 -30]);
axis off, gridm on, framem on;
setm(ha,'MLineLocation',15,'PLineLocation',15);
mlabel on, plabel on;
%load coastlines;
hg = geoshow('landareas.shp'); %geoshow(coastlat,coastlon,'displaytype','line','color','b');


geoshow(latpts,lonpts,'displaytype','line')
geoshow(gcpts(:,1),gcpts(:,2),'DisplayType','line',...
    'color','red','linestyle','--')
geoshow(rhpts(:,1),rhpts(:,2),'DisplayType','line',...
    'color','green','linestyle','-.')

%% Calculate distances if wanted
% drh = distance('rh',origin,destination); % Get rhumb line dist (deg)
% dgc = distance('gc',origin,destination); % Get gt. circle dist (deg)
% % Compute headings and distances for the waypoint legs
% [course, distnm] = legs(latpts,lonpts,'rh');
% 
% distrhnm = deg2nm(drh)            % Nautical mi along rhumb line
% distgcnm = deg2nm(dgc)            % Nautical mi along great circle
% distlegsnm = sum(distnm)          % Total dist along the N legs
% rhgcdiff = distrhnm - distgcnm    % Excess rhumb line distance
% trgcdiff = distlegsnm - distgcnm  % Excess distance along legs

end