%% Calculates total resistance. Uses waveres results for calm water resistance, done by interpolation.
%  Calculates added resistance by running Veres in batch mode. 
%
% Author:   Martin Bakke and Peter Tenfjord
% Date:     01.06.2017


%% Function
function [R, Raw] = run_shipx(Vreq, Hs_sea, Hsd_sea, Tp_sea, Hs_swl, Hsd_swl, Tp_swl, Resistance_Table, num)
% R - calm water resistance
% Raw - added resistance
%% Parameters and Constants
rho = 1025; % density of sea water [kg/m^3]
g = 9.81; % acceleration [m/s^2]
Lpp = num(1); % Vessel length perperndiculars [m]
B = num(4); % Vessel beam [m]

%% For Simulink these are needed
coder.extrinsic('system')
coder.extrinsic('fopen')
coder.extrinsic('fgetl')
coder.extrinsic('str2num')
coder.extrinsic('delete')
coder.extrinsic('dlmread')
coder.extrinsic('num2str')

%% Making the direction between 0 and 180 degrees
  
Hsd_sea = acosd(cosd(Hsd_sea));
Hsd_swl = acosd(cosd(Hsd_swl));

%% Veres run for sea

InputWrite(Vreq,Hs_sea,Hsd_sea);

system('"C:\Users\Martin\OneDrive - NTNU\Matlab\Progging_master\RunVeres.bat"'); % Running Veres in batch mode
Sea_Vec = zeros(31,10);
Sea_Vec = dlmread('input.re2','',10); % Reading output file
delete('input.hyd','input.log','input.out','input.re1','input.re2','input.str','input.swy','input.veres')

% len = length(Sea_Vec);
len = 31;
freq_sea = zeros(len,1);
sup_sea = zeros(len,1);
S_sea = zeros(len,1);
CRAW_sea = zeros(len,1);
ADDEDR_sea = 0;
C_sea = zeros(len,1);

freq_sea = Sea_Vec(1:len,1); % Reading frequency vector
S_sea  = wavespec(4,[Hs_sea, Tp_sea],freq_sea,0); % Creating wavespectrum, 4 is for Pierson-Moskowitz

CRAW_sea = Sea_Vec(1:len,2); % Added resistance operator from shipx
sup_sea = times(S_sea,CRAW_sea); % Multiplying added resistance operator with wavespectrum
ADDEDR_sea = 2*trapz(freq_sea,sup_sea); % Integrating over the frequency domain
if Hs_swl == 0
    Raw_sea = 0;
else
    Raw_sea = (ADDEDR_sea*rho*g*B^2)/Lpp; % Calculating added resistance
end

%% Veres run for swell

InputWrite(Vreq,Hs_swl,Hsd_swl);

system('"C:\Users\Martin\OneDrive - NTNU\Matlab\Progging_master\RunVeres.bat"');
Swl_Vec = zeros(31,10);
Swl_Vec = dlmread('input.re2','',10);
delete('input.hyd','input.log','input.out','input.re1','input.re2','input.str','input.swy','input.veres')

len = length(Swl_Vec);
freq_swl = zeros(len,1);
sup_swl = zeros(len,1);
S_swl = zeros(len,1);
CRAW_swl = zeros(len,1);
ADDEDR_swl = 0;
C_swl = zeros(len,1);

freq_swl = Swl_Vec(1:len,1);
S_swl  = wavespec(4,[Hs_swl, Tp_swl],freq_swl,0);

CRAW_swl = Swl_Vec(1:len,2);
sup_swl = times(S_swl,CRAW_swl);
ADDEDR_swl = 2*trapz(freq_swl,sup_swl);
if Hs_swl == 0
    Raw_swl = 0;
else
    Raw_swl = (ADDEDR_swl*rho*g*B^2)/Lpp;
end

%% Calculation of Resistance
R = interp1(Resistance_Table(:,1),Resistance_Table(:,2),Vreq); % Calm water resistance

Raw = Raw_sea + Raw_swl; % Added resistance

end