function [MC, StateValue]=MC_param(CSVfile,numStates,first_month,last_month, col)

MC = zeros(numStates);
StateValue = zeros(1,numStates);

%% Making sure there are no absorbing states in the final matrix
absStates = 2;
while absStates >= 1 && numStates > 0
    
% Reads the csv file from waveclimate.com into a matrix
A = csvread(CSVfile,23,0);

% Set first and last month. Can be the same<
firstMonth = first_month;
lastMonth = last_month;

% Loop over all the rows in the matrix
for i = 1:size(A,1)
%     Check if the month is in the range wanted
    if (A(i,2) >= firstMonth) && (A(i,2) <= lastMonth)
        if A(i,col) > 0 && A(i,col) < 999 % Disregard zero and negative values
            if (exist('Param') == 0) % Param doesn't exist
                Param = A(i,col);
            else
                % Add the value at the end of the chosen parameter
                % Sets the parameter equal to Param + the additional row which is the
                % value from A(i,col)
                Param = [ Param; A(i,col) ];
            end
        end
    end
end

% Set number of states in the markov chain
% 
% Beware of setting this too high. If there are too many states, some of
% the states will be absorbing, that is, P(j,j) = 1, which means it can
% never transition to other states.

% Find upper limit for parameter values and divide the values into even bins
ul = max(Param);
umin = min(Param);
% Find state ranges - first state [0,stateRange] and so on
stateRange = ul / numStates;
% Make vector with real size corresponding to state
BigRange = linspace(umin,ul,2*numStates+1);
k=1;
Range = zeros(1,numStates);
for i=2:2:2*numStates+1
    Range(k)=BigRange(i);
    k=k+1;
end
% State values - stateRange, 2xstateRange and so on up til ul
stateValues = stateRange:stateRange:ul;
% Initialize 1D-matrix holding the state of each data point
ParamState = zeros(length(Param),1);

% Find each data points state
for i = 1:length(Param)
    % For each data point
    for j = 1:numStates
        % For each state
        if Param(i) <= stateValues(j)
            % Data point is in state j
            ParamState(i) = j;
            % This data point is categorized, so we break and move to the
            % next data point
            break;
        end
    end
end

% Find transitions
transitions = zeros(numStates);
for t = 1:length(ParamState)-1
    % ParamState(t) represents the state and ParamState(t+1) represents the state
    % it transitions to
    transitions(ParamState(t),ParamState(t+1)) = transitions(ParamState(t),ParamState(t+1)) + 1;
end

P = transitions;
% Normalize each row in the transition matrix so each row sums to 1
for i = 1:numStates
    P(i,:) = P(i,:) / sum( P(i,:) );
end

% Check to see if there are any absorbing states
% i.e. P(i,j) == 1 where i=j
absorbstate = zeros(numStates);
for i = 1:numStates
    for j = 1:numStates
        if P(i,j) == 1
            absorbstate(i,j) = absorbstate(i,j) + 1;
        end
    end
end

absStates = sum(sum(absorbstate));
numStates = numStates-1;

end  

if numStates == 0
  P = 1;
  Range = mean(Param);
end

% Making all matrices the size of numstates x numstates
%  Easier to work with when making 3D matrices

[A, B] = NaNtoZero(P,Range);

MC(1:length(A),1:length(A)) = A;
StateValue(1:length(B)) = B;

end 
% Transition matrix is now ready